==> webgme-user-management-page-0.2.0.tgz: package/src/common/components/content/widgets/data_tables/UsersTable.jsx <==
/**
 * Container widget for the users data table
 * @author patrickkerrypei / https://github.com/patrickkerrypei
 */

// Libraries
import React, { Component, PropTypes } from 'react';
import { Button } from 'react-bootstrap';
import { Link } from 'react-router';
// Self-defined
import DataTable from './DataTable';
import UsersDataTableEntry from
    '../../../../containers/content/widgets/data_tables/table_entries/UsersDataTableEntry';
import { fetchUsersIfNeeded } from '../../../../actions/users';
import { fetchUserIfNeeded } from '../../../../actions/user';
import { sortBy } from '../../../../actions/tables';

const USERS_FIELDS = {
    User: "_id"
};

export default class UsersTable extends Component {

    constructor(props) {
        super(props);
        // Event handlers
        this.handleOrderEntries = this.handleOrderEntries.bind(this);
    }

    componentDidMount() {
        const { dispatch } = this.props;

        dispatch(fetchUsersIfNeeded());
        dispatch(fetchUserIfNeeded());
    }

    handleOrderEntries(event) {
        const { dispatch } = this.props;
        const newSortCategory = USERS_FIELDS[event.target.innerHTML];

        dispatch(sortBy('users', newSortCategory));
    }

    render() {

        const { sortedForward, user, users } = this.props;
        const categories = [
            {id: 1, name: 'User'}
        ];

        return (

            <div>
                {/* Header */}
                <div className="box-header"
                     style={{paddingBottom: "0px"}}>
                    <h3 className="box-title" style={{fontSize: 28}}>
                        <i className="fa fa-users"/> {` Users`}
                    </h3>
                    <Link to={`${this.props.basePath}newuser`}>
                    <Button className="pull-right"
                            bsStyle="primary"
                            bsSize="small"
                            style={this.props.user.siteAdmin === true ? {} : {display: 'none'}}
                            onClick={this.toggleModal}>
                        Add +

                    </Button>
                    </Link>
                </div>

                {/* Body */}
                <DataTable categories={categories}
                           content="Users"
                           entries={users}
                           orderEntries={this.handleOrderEntries}
                           sortable={true}
                           sortedForward={sortedForward}>
                    <UsersDataTableEntry columnStyle={{width: "13%"}}
                                         userId={user._id} />
                </DataTable>
            </div>
        );
    }
}

UsersTable.propTypes = {
    sortCategory: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.array
    ]).isRequired,
    sortedForward: PropTypes.bool.isRequired,
    users: PropTypes.array.isRequired,
    restClient: PropTypes.object.isRequired,
    basePath: PropTypes.string.isRequired,
    user: PropTypes.object.isRequired
};

==> webgme-user-management-page-0.3.4.tgz: package/src/common/components/content/widgets/data_tables/UsersTable.jsx <==
/**
 * Container widget for the users data table
 * @author patrickkerrypei / https://github.com/patrickkerrypei
 */

// Libraries
import React, { Component, PropTypes } from 'react';
import { Button } from 'react-bootstrap';
import { Link } from 'react-router';
// Self-defined
import DataTable from '../../../../containers/content/widgets/data_tables/DataTable';
import UsersDataTableEntry from
    '../../../../containers/content/widgets/data_tables/table_entries/UsersDataTableEntry';
import { fetchUsersIfNeeded } from '../../../../actions/users';
import { fetchUserIfNeeded } from '../../../../actions/user';

export default class UsersTable extends Component {

    constructor(props) {
        super(props);
    }

    componentDidMount() {
        const { dispatch } = this.props;

        dispatch(fetchUsersIfNeeded());
        dispatch(fetchUserIfNeeded());
    }

    render() {
        const { user, users } = this.props;
        const categories = [
            {id: 1, name: 'User'}
        ];

        return (
            <div>
                {/* Header */}
                <div className="box-header"
                     style={{paddingBottom: "0px"}}>
                    <h3 className="box-title" style={{fontSize: 28}}>
                        <i className="fa fa-users"/> {` Users`}
                    </h3>
                    <Link to={`${this.props.basePath}newuser`}>
                    <Button className="pull-right"
                            bsStyle="primary"
                            bsSize="small"
                            style={this.props.user.siteAdmin === true ? {} : {display: 'none'}}
                            onClick={this.toggleModal}>
                        Add +

                    </Button>
                    </Link>
                </div>

                {/* Body */}
                <DataTable categories={categories}
                           content="Users"
                           entries={users}
                           orderEntries={this.handleOrderEntries}
                           reducerTableName="users"
                           sortable={true}>
                    <UsersDataTableEntry columnStyle={{width: "13%"}}
                                         userId={user._id} />
                </DataTable>
            </div>
        );
    }
}

UsersTable.propTypes = {
    sortCategory: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.array
    ]).isRequired,
    sortedForward: PropTypes.bool.isRequired,
    users: PropTypes.array.isRequired,
    restClient: PropTypes.object.isRequired,
    basePath: PropTypes.string.isRequired,
    user: PropTypes.object.isRequired
};
